@@ -13,25 +13,37 @@ from .events import (
     EventCheckin,
 )
 
+from .maps import (
+    Pip,
+)
+
 from .meetings import (
     Meeting,
     TravelersMet,
 )
 
-from .news import (
-    RedditSubmission,
-)
-
-from .users import (
-    User,
-    UserLogin,
-    UnlockedAvatar,
-    UserBadge,
-)
-
 from .nests import (
     Nest,
     NestVerification,
     NestAdvice,
     NestMigration,
 )
+
+from .news import (
+    RedditSubmission,
+)
+
+from .pokemon import (
+    Pokemon,
+    PokemonType,
+)
+
+from .users import (
+    Avatar,
+    Badge,
+    TravelersCard,
+    User,
+    UserLogin,
+    UnlockedAvatar,
+    UserBadge,
+)
